@@ -6,12 +6,11 @@ use warnings;
 our $VERSION = 0;
 
 use Object::Lazy;
+use Data::Dumper;
 
 my $object = Object::Lazy->new(
     sub {
-        # A lazy Data::Dumper object as example
-        # will show you use or require late too.
-        require Data::Dumper;
+        # A lazy Data::Dumper object as example.
         return Data::Dumper->new(['data'], ['my_dump']);
     },
 );
@@ -27,8 +26,8 @@ sub do_something_with {
         # the Data::Dumper object is not created
     }
     () = print
-        "\$condition = $condition;\n",
-        qq{'$object' = "\$object";\n};
+        "condition = $condition\n",
+        "object = $object\n";
 
     return;
 }
@@ -39,4 +38,14 @@ do_something_with($object, 0);
 # build the real object and call method Dump
 do_something_with($object, 1);
 
-# $Id$
\ No newline at end of file
+# $Id$
+
+__END__
+
+output:
+
+condition = 0
+object = Object::Lazy=HASH(...)
+$my_dump = 'data';
+condition = 1
+object = Data::Dumper=HASH(...)
